@@ -60,7 +60,7 @@ class Request(BaseModel):
     type: RequestType
     connection: Connection
     body: Any
-    origHost: Optional[str]
+    host: Optional[str]
     syncariId: Optional[str]
     requestId: Optional[str]
 
